
.. include:: README.rst

.. toctree::
    :hidden:
    :maxdepth: 3

    quickstart
    data/index
    patches/index
    transforms/transforms
    datasets
    interfaces/index
    auto_examples/index
    GitHub repository <https://github.com/TorchIO-project/torchio>
    Paper <https://www.sciencedirect.com/science/article/pii/S0169260721003102>
